<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="kk">
<context>
    <name>main</name>
    <message>
        <source>WLAN on</source>
        <translation>WLAN жетісі</translation>
    </message>
    <message>
        <source>WLAN off</source>
        <translation>WLAN жетісі бекітілген</translation>
    </message>
    <message>
        <source>Caps Lock on</source>
        <translation>Caps Lock жетісі</translation>
    </message>
    <message>
        <source>Caps Lock off</source>
        <translation>Caps Lock жетісі бекітілген</translation>
    </message>
    <message>
        <source>Numeric keypad on</source>
        <translation>Нумералдық панелді жетісі</translation>
    </message>
    <message>
        <source>Numeric keypad off</source>
        <translation>Нумералдық панелді жетісі бекітілген</translation>
    </message>
    <message>
        <source>Touchpad on</source>
        <translation>Түстік панелді жетісі</translation>
    </message>
    <message>
        <source>Touchpad off</source>
        <translation>Түстік панелді жетісі бекітілген</translation>
    </message>
    <message>
        <source>Touchpad toggle</source>
        <translation>Түстік панельді түзет</translation>
    </message>
    <message>
        <source>Fn toggle</source>
        <translation>Fn түзет</translation>
    </message>
    <message>
        <source>Airplane mode on</source>
        <translation>Соңырақ режимі жетісі</translation>
    </message>
    <message>
        <source>Airplane mode off</source>
        <translation>Соңырақ режимі жетісі бекітілген</translation>
    </message>
    <message>
        <source>Balanced power</source>
        <translation>Жалпысыз энергиялық режим</translation>
    </message>
    <message>
        <source>Power saver</source>
        <translation>Энергиялық экономия режимі</translation>
    </message>
    <message>
        <source>High performance</source>
        <translation>Көп жұмыс істеу режимі</translation>
    </message>
    <message>
        <source>Window effect enabled</source>
        <translation>Квадраттардың ефекті әртүрлі кестесі</translation>
    </message>
    <message>
        <source>Window effect disabled</source>
        <translation>Квадраттардың ефекті әртүрлі кестесі бекітілген</translation>
    </message>
    <message>
        <source>Failed to enable window effects</source>
        <translation>Квадраттардың ефекті әртүрлі кестесін қатыстыру қателесі</translation>
    </message>
    <message>
        <source>Microphone off</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Microphone on</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>